@@ -5,12 +5,14 @@ TODO
     - .contains(selector)
     - .isSubselector(selector)
 """
+
 __all__ = ['Selector']
 
+import xml.dom
+
+import cssutils
 from cssutils.helper import Deprecated
 from cssutils.util import _SimpleNamespaces
-import cssutils
-import xml.dom
 
 
 class Selector(cssutils.util.Base2):
@@ -126,7 +128,7 @@ class Selector(cssutils.util.Base2):
             st = (self.selectorText, self._getUsedNamespaces())
         else:
             st = self.selectorText
-        return "cssutils.css.{}(selectorText={!r})".format(self.__class__.__name__, st)
+        return f"cssutils.css.{self.__class__.__name__}(selectorText={st!r})"
 
     def __str__(self):
         return (
@@ -181,9 +183,10 @@ class Selector(cssutils.util.Base2):
         "namespaceURI} is used.",
     )
 
-    element = property(
-        lambda self: self._element, doc="Effective element target of this selector."
-    )
+    @property
+    def element(self):
+        """Effective element target of this selector."""
+        return self._element
 
     parent = property(
         lambda self: self._parent,
@@ -328,7 +331,7 @@ class Selector(cssutils.util.Base2):
             # used for equality checks and setting of a space combinator
             S = ' '
 
-            def append(seq, val, typ=None, token=None):
+            def append(seq, val, typ=None, token=None):  # noqa: C901
                 """
                 appends to seq
 
@@ -651,7 +654,7 @@ class Selector(cssutils.util.Base2):
                     self._log.error('Selector: Unexpected HASH.', token=token)
                     return expected
 
-            def _char(expected, seq, token, tokenizer=None):
+            def _char(expected, seq, token, tokenizer=None):  # noqa: C901
                 # + > ~ ) [ ] + -
                 context = new['context'][-1]
                 val = self._tokenvalue(token)
